summaryrefslogtreecommitdiff
path: root/EmbeddedPkg/EblExternCmd
diff options
context:
space:
mode:
authoroliviermartin <oliviermartin@6f19259b-4bc3-4df7-8a09-765794883524>2011-08-08 18:29:14 +0000
committeroliviermartin <oliviermartin@6f19259b-4bc3-4df7-8a09-765794883524>2011-08-08 18:29:14 +0000
commit7ca9e5a4010b0e16231173dfc1918685ffc3a1dd (patch)
treec242f6837827c6289131c5653be7993ae058a20d /EmbeddedPkg/EblExternCmd
parent573d7e468eb83505a20ae3f828b67599cda23b3d (diff)
downloadedk2-platforms-7ca9e5a4010b0e16231173dfc1918685ffc3a1dd.tar.xz
EmbeddedPkg: Fix mispellings
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@12101 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'EmbeddedPkg/EblExternCmd')
-rw-r--r--EmbeddedPkg/EblExternCmd/EntryPointGlue.c22
-rw-r--r--EmbeddedPkg/EblExternCmd/Main.c2
2 files changed, 12 insertions, 12 deletions
diff --git a/EmbeddedPkg/EblExternCmd/Main.c b/EmbeddedPkg/EblExternCmd/Main.c
index 9a3dcce74c..9f38c5de58 100644
--- a/EmbeddedPkg/EblExternCmd/Main.c
+++ b/EmbeddedPkg/EblExternCmd/Main.c
@@ -29,7 +29,7 @@
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
diff --git a/EmbeddedPkg/EblExternCmd/EntryPointGlue.c b/EmbeddedPkg/EblExternCmd/EntryPointGlue.c
index dd6cbed9ec..cffd844bd0 100644
--- a/EmbeddedPkg/EblExternCmd/EntryPointGlue.c
+++ b/EmbeddedPkg/EblExternCmd/EntryPointGlue.c
@@ -17,7 +17,7 @@
**/
-#define CMD_SEPERATOR ';'
+#define CMD_SEPARATOR ';'
#define MAX_ARGS 32
EFI_STATUS
@@ -35,7 +35,7 @@ EblMain (
/**
Parse the CmdLine and break it up into Argc (arg count) and Argv (array of
- pointers to each argument). The Cmd buffer is altered and seperators are
+ pointers to each argument). The Cmd buffer is altered and separators are
converted to string terminators. This allows Argv to point into CmdLine.
A CmdLine can support multiple commands. The next command in the command line
is returned if it exists.
@@ -67,18 +67,18 @@ ParseArguments (
return;
}
// Walk a single command line. A CMD_SEPERATOR allows mult commands on a single line
InQuote = FALSE;
LookingForArg = TRUE;
- for (Char = CmdLine, Arg = 0, Index = 0; *Char != '\0' && *Char != CMD_SEPERATOR; Char++, Index++) {
- // Perform any text coversion here
+ for (Char = CmdLine, Arg = 0, Index = 0; *Char != '\0' && *Char != CMD_SEPARATOR; Char++, Index++) {
+ // Perform any text conversion here
if (*Char == '\t') {
// TAB to space
*Char = ' ';
}
if (LookingForArg) {
- // Look for the beging of an Argv[] entry
+ // Look for the beginning of an Argv[] entry
if (*Char == '"') {
Argv[Arg++] = ++Char;
LookingForArg = FALSE;
@@ -103,8 +103,8 @@ ParseArguments (
*Argc = Arg;
- if (*Char == CMD_SEPERATOR) {
- // Replace the command delimeter with null
+ if (*Char == CMD_SEPARATOR) {
+ // Replace the command delimiter with null
*Char = '\0';
}
@@ -116,14 +116,14 @@ ParseArguments (
/**
Embedded Boot Loader (EBL) - A simple EFI command line application for embedded
- devices. PcdEmbeddedAutomaticBootCommand is a complied in commnad line that
- gets executed automatically. The ; seperator allows multiple commands
+ devices. PcdEmbeddedAutomaticBootCommand is a complied in command line that
+ gets executed automatically. The ; separator allows multiple commands
for each command line.
@param ImageHandle EFI ImageHandle for this application.
@param SystemTable EFI system table
- @return EFI status of the applicaiton
+ @return EFI status of the application
**/
EFI_STATUS
@@ -67,18 +67,18 @@ ParseArguments (
return;
}
- // Walk a single command line. A CMD_SEPERATOR allows mult commands on a single line
+ // Walk a single command line. A CMD_SEPARATOR allows multiple commands on a single line
InQuote = FALSE;
LookingForArg = TRUE;